# Table of Contents

- [sap-signavio-integration](<./sap-signavio-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Signavio Integration](<./SAP-Signavio-Integration.md>)
  - [Introduction](<./SAP-Signavio-Integration/Introduction.md>)
  - [Benefits of the Integration](<./SAP-Signavio-Integration/Benefits-of-the-Integration.md>)
  - [Scope of the Integration](<./SAP-Signavio-Integration/Scope-of-the-Integration.md>)
  - [Getting Started with the Integration](<./SAP-Signavio-Integration/Getting-Started-with-the-Integration.md>)
  - [Filtering for Linked Fact Sheets in Inventory and Reports](<./SAP-Signavio-Integration/Filtering-for-Linked-Fact-Sheets-in-Inventory-and-Reports.md>)
  - [Leveraging Reports for Analysis](<./SAP-Signavio-Integration/Leveraging-Reports-for-Analysis.md>)
  - [Accessing Linked Items across SAP LeanIX and SAP Signavio](<./SAP-Signavio-Integration/Accessing-Linked-Items-across-SAP-LeanIX-and-SAP-Signavio.md>)
  - [Viewing Synchronization Logs](<./SAP-Signavio-Integration/Viewing-Synchronization-Logs.md>)
